Learn R Programming

pins (version 0.4.2)

board_register_azure: Register Azure Board

Description

Wrapper with explicit parameters over board_register() to register a Microsoft Azure Storage Blob as a board.

Usage

board_register_azure(
  name = "azure",
  container = Sys.getenv("AZURE_STORAGE_CONTAINER"),
  account = Sys.getenv("AZURE_STORAGE_ACCOUNT"),
  key = Sys.getenv("AZURE_STORAGE_KEY"),
  cache = board_cache_path(),
  ...
)

Arguments

name

Optional name for this board, defaults to 'azure'.

container

The name of the Azure Storage container. Defaults to the AZURE_STORAGE_CONTAINER environment variable.

account

The account of the Azure Storage container. Defaults to the AZURE_STORAGE_ACCOUNT environment variable.

key

The key of the Azure Storage container Defaults to the AZURE_STORAGE_KEY environment variable.

cache

The local folder to use as a cache, defaults to board_cache_path().

...

Additional parameters required to initialize a particular board.

Details

This function requires an Azure Storage container to be manually created; otherwise, registering an Azire board will fail.

See Also

board_register

Examples

Run this code
# NOT RUN {
# the following example requires an Azure Storage key
board_register_azure(container = "pinscontainer",
                     account = "pinsstorage",
                     key = "abcabcabcabcabcabcabcabcabcab==")
# }

Run the code above in your browser using DataLab