Learn R Programming

pins (version 0.1.0)

board_register_datatxt: Register Data TXT Board

Description

Wrapper with explicit parameters over board_register() to register as a board a website describing resources with a data.txt file.

Usage

board_register_datatxt(name, url)

Arguments

name

The name for this board, usually the domain name of the website.

url

Path to the data.txt file or path containing it.

See Also

board_register

Examples

Run this code
# NOT RUN {
# register website board using datatxt file
board_register_datatxt(name = "txtexample", url = "https://datatxt.org/data.txt")

# find pins
pin_find(board = "txtexample")

# }

Run the code above in your browser using DataLab