Learn R Programming

pins (version 0.4.2)

board_register_gcloud: Register Google Cloud Board

Description

Wrapper with explicit parameters over board_register() to register a Google Cloud Storage container as a board.

Usage

board_register_gcloud(
  name = "gcloud",
  bucket = Sys.getenv("GCLOUD_STORAGE_BUCKET"),
  token = NULL,
  cache = board_cache_path(),
  ...
)

Arguments

name

Optional name for this board, defaults to 'gcloud'.

bucket

The name of the Google Cloud Storage bucket. Defaults to the GCLOUD_STORAGE_BUCKET environment variable.

token

The access token of the Google Cloud Storage container. Defaults to use the Google Cloud SDK if configured.

cache

The local folder to use as a cache, defaults to board_cache_path().

...

Additional parameters required to initialize a particular board.

Details

This function requires a Google Cloud Storage container to be manually created; otherwise, registering a Google Cloud board will fail.

See Also

board_register

Examples

Run this code
# NOT RUN {
# the following example requires the Google Cloud SDK to be configured
board_register_gcloud(container = "gcloudcontainer")
# }

Run the code above in your browser using DataLab