Learn R Programming

pins (version 0.4.2)

board_register_kaggle: Register Kaggle Board

Description

Wrapper with explicit parameters over board_register() to register Kaggle as a board.

Usage

board_register_kaggle(
  name = "kaggle",
  token = NULL,
  overwrite = FALSE,
  cache = board_cache_path(),
  ...
)

Arguments

name

Optional name for this board, defaults to 'kaggle'.

token

The Kaggle token as a path to the kaggle.json file, can be NULL if the ~/.kaggle/kaggle.json file already exists.

overwrite

Should ~/.kaggle/kaggle.json be overriden?

cache

The local folder to use as a cache, defaults to board_cache_path().

...

Additional parameters required to initialize a particular board.

See Also

board_register

Examples

Run this code
# NOT RUN {
# the following example requires a Kaggle API token
board_register_kaggle(token = "path/to/kaggle.json")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab