powered by
Deregisters a board, useful to disable boards no longer in use. This operation removes all locally cached pins.
board_deregister(name)
An optional name to identify this board, defaults to the board name.
# NOT RUN { # create a new local board board_register("local", "other_board") # pin iris to new board pin(iris, board = "other_board") # deregister new board board_deregister("other_board") # }
Run the code above in your browser using DataLab