powered by
Registers a board, useful to add sources to pin_find() or pin to remote boards with pin().
pin_find()
pin()
board_register(board, name = board, ...)
The name of the board to register.
An optional name to identify this board, defaults to the board name.
Additional parameters required to initialize a particular board.
board_register_github, board_register_kaggle, board_register_rsconnect and board_register_datatxt.
board_register_github
board_register_kaggle
board_register_rsconnect
board_register_datatxt
# NOT RUN { # create a new local board board_register("local", "other_board") # create a Website board board_register("datatxt", name = "txtexample", url = "https://datatxt.org/data.txt") # }
Run the code above in your browser using DataLab