The name of the Amazon S3 bucket. Defaults to the AWS_BUCKET environment
variable.
key
The key of the Amazon S3 bucket. Defaults to the AWS_ACCESS_KEY_ID environment
variable.
secret
The secret of the Amazon S3 bucket. Defaults to the AWS_SECRET_ACCESS_KEY environment
variable.
cache
The local folder to use as a cache, defaults to board_cache_path().
host
The host to use for storage, defaults to "s3.amazonaws.com".
region
The region to use, required in some AWS regions and to enable V4 signatures.
path
The subdirectory in the repo where the pins will be stored.
...
Additional parameters required to initialize a particular board.
Details
This function requires an Amazon S3 bucket to be manually created; otherwise,
registering an S3 board will fail.
When the region parameter is not specified, pins defaults to using AWS V2 signatures;
therefore, it is recommended to specify the region to ensure pins makes use of AWS V4 signatures.