powered by
Wrapper with explicit parameters over board_register() to register an Amazon S3 bucket as a board.
board_register()
board_register_s3( name = "s3", bucket = Sys.getenv("AWS_BUCKET"), key = Sys.getenv("AWS_ACCESS_KEY_ID"), secret = Sys.getenv("AWS_SECRET_ACCESS_KEY"), cache = board_cache_path(), host = "s3.amazonaws.com", ... )
Optional name for this board, defaults to 's3'.
The name of the Amazon S3 bucket. Defaults to the AWS_BUCKET environment variable.
AWS_BUCKET
The key of the Amazon S3 bucket. Defaults to the AWS_ACCESS_KEY_ID environment variable.
AWS_ACCESS_KEY_ID
The secret of the Amazon S3 bucket. Defaults to the AWS_SECRET_ACCESS_KEY environment variable.
AWS_SECRET_ACCESS_KEY
The local folder to use as a cache, defaults to board_cache_path().
board_cache_path()
The host to use for storage, defaults to "s3.amazonaws.com".
"s3.amazonaws.com"
Additional parameters required to initialize a particular board.
This function requires an Amazon S3 bucket to be manually created; otherwise, registering an S3 board will fail.
board_register
# NOT RUN { # the following example requires an Amazon S3 API key board_register_s3(bucket = "s3bucket") # }
Run the code above in your browser using DataLab